@@ -54,27 +54,24 @@ public:
     /**
       Destroys this job.
     */
-    virtual ~PrecommandJob();
+    ~PrecommandJob() override;
 
     /**
       Executes the precommand.
       Reimplemented from KJob.
     */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 protected:
 
     /**
       Reimplemented from KJob.
     */
-    bool doKill() Q_DECL_OVERRIDE;
+    bool doKill() override;
 
 private:
     friend class ::PreCommandJobPrivate;
     PreCommandJobPrivate *const d;
-    Q_PRIVATE_SLOT(d, void slotFinished(int, QProcess::ExitStatus))
-    Q_PRIVATE_SLOT(d, void slotStarted())
-    Q_PRIVATE_SLOT(d, void slotError(QProcess::ProcessError error))
 };
 } // namespace MailTransport
 
