@@ -62,17 +62,30 @@ TransportManagementWidget::TransportManagementWidget(QWidget *parent)
     d->updateButtonState();
 
     d->ui.transportList->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(d->ui.transportList, SIGNAL(currentItemChanged(QTreeWidgetItem *,QTreeWidgetItem *)),
-            SLOT(updateButtonState()));
-    connect(d->ui.transportList, SIGNAL(itemDoubleClicked(QTreeWidgetItem *,int)),
-            SLOT(editClicked()));
-    connect(d->ui.addButton, SIGNAL(clicked()), SLOT(addClicked()));
-    connect(d->ui.editButton, SIGNAL(clicked()), SLOT(editClicked()));
-    connect(d->ui.renameButton, SIGNAL(clicked()), SLOT(renameClicked()));
-    connect(d->ui.removeButton, SIGNAL(clicked()), SLOT(removeClicked()));
-    connect(d->ui.defaultButton, SIGNAL(clicked()), SLOT(defaultClicked()));
-    connect(d->ui.transportList, SIGNAL(customContextMenuRequested(QPoint)),
-            SLOT(slotCustomContextMenuRequested(QPoint)));
+    connect(d->ui.transportList, &QTreeWidget::currentItemChanged, this, [this]() {
+        d->updateButtonState();
+    });
+    connect(d->ui.transportList, &QTreeWidget::itemDoubleClicked, this, [this]() {
+        d->editClicked();
+    });
+    connect(d->ui.addButton, &QPushButton::clicked, this, [this]() {
+        d->addClicked();
+    });
+    connect(d->ui.editButton, &QPushButton::clicked, this, [this]() {
+        d->editClicked();
+    });
+    connect(d->ui.renameButton, &QPushButton::clicked, this, [this]() {
+        d->renameClicked();
+    });
+    connect(d->ui.removeButton, &QPushButton::clicked, this, [this]() {
+        d->removeClicked();
+    });
+    connect(d->ui.defaultButton, &QPushButton::clicked, this, [this]() {
+        d->defaultClicked();
+    });
+    connect(d->ui.transportList, &QTreeWidget::customContextMenuRequested, this, [this](QPoint p) {
+        d->slotCustomContextMenuRequested(p);
+    });
 }
 
 TransportManagementWidget::~TransportManagementWidget()
@@ -157,20 +170,29 @@ void TransportManagementWidget::Private::defaultClicked()
 
 void TransportManagementWidget::Private::slotCustomContextMenuRequested(const QPoint &pos)
 {
-    QMenu *menu = new QMenu(q);
-    menu->addAction(i18n("Add..."), q, SLOT(addClicked()));
+    QMenu menu(q);
+    menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add..."), q, [this]() {
+        addClicked();
+    });
     QTreeWidgetItem *item = ui.transportList->itemAt(pos);
     if (item) {
-        menu->addAction(i18n("Modify..."), q, SLOT(editClicked()));
-        menu->addAction(i18n("Rename"), q, SLOT(renameClicked()));
-        menu->addAction(i18n("Remove"), q, SLOT(removeClicked()));
+        menu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Modify..."), q, [this]() {
+            editClicked();
+        });
+        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18n("Rename"), q, [this]() {
+            renameClicked();
+        });
+        menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("Remove"), q, [this]() {
+            removeClicked();
+        });
         if (item->data(0, Qt::UserRole) != TransportManager::self()->defaultTransportId()) {
-            menu->addSeparator();
-            menu->addAction(i18n("Set as Default"), q, SLOT(defaultClicked()));
+            menu.addSeparator();
+            menu.addAction(i18n("Set as Default"), q, [this]() {
+                defaultClicked();
+            });
         }
     }
-    menu->exec(ui.transportList->viewport()->mapToGlobal(pos));
-    delete menu;
+    menu.exec(ui.transportList->viewport()->mapToGlobal(pos));
 }
 
 #include "moc_transportmanagementwidget.cpp"
