@@ -40,23 +40,16 @@ public:
       Creates a new TransportManagementWidget.
       @param parent The parent widget.
     */
-    TransportManagementWidget(QWidget *parent = nullptr);
+    explicit TransportManagementWidget(QWidget *parent = nullptr);
 
     /**
       Destroys the widget.
     */
-    virtual ~TransportManagementWidget();
+    ~TransportManagementWidget() override;
 
 private:
     class Private;
     Private *const d;
-    Q_PRIVATE_SLOT(d, void defaultClicked())
-    Q_PRIVATE_SLOT(d, void removeClicked())
-    Q_PRIVATE_SLOT(d, void renameClicked())
-    Q_PRIVATE_SLOT(d, void editClicked())
-    Q_PRIVATE_SLOT(d, void addClicked())
-    Q_PRIVATE_SLOT(d, void updateButtonState())
-    Q_PRIVATE_SLOT(d, void slotCustomContextMenuRequested(const QPoint &))
 };
 } // namespace MailTransport
 
