@@ -44,7 +44,7 @@ public:
     FilterActionJob *q;
     Collection collection;
     Item::List items;
-    FilterAction *functor;
+    FilterAction *functor = nullptr;
     ItemFetchScope fetchScope;
 
     // Q_SLOTS:
@@ -127,7 +127,9 @@ void FilterActionJob::doStart()
         Q_ASSERT(d->functor);
         d->fetchScope = d->functor->fetchScope();
         fjob->setFetchScope(d->fetchScope);
-        connect(fjob, SIGNAL(result(KJob *)), this, SLOT(fetchResult(KJob *)));
+        connect(fjob, &ItemFetchJob::result, this, [this](KJob *job) {
+            d->fetchResult(job);
+        });
     } else {
         d->traverseItems();
     }
